@@ -191,16 +191,22 @@ branch_combine <- function(m, o, f, margs){
 }
 
 default_combine <- function(m, o, f, margs){
+
   if(!m_OK(o)){
     # On failure, propagate the final passing value, this allows
     # for either degugging or passage to alternative handlers.
-    m_value(o) <- m_value(m, warn=FALSE)
+    val <- m_value(m, warn=FALSE)
   }
 
   if(has_nest(o)){
     m_nest(o) <- splice_function(f=f, m=m_nest(o), ms=margs)
+    if(!m_OK(o)){
+      m_value(m_nest(o)) <- m_value(o)
+    }
   }
 
+  if(!m_OK(o)) m_value(o) <- val
+
   o$inherit(parents=m)
 
   o
